@@ -6,7 +6,7 @@ def read_bool_setting(settings, setting_name, default=False):
             return False if s_int == 0 else True
         else:
             return default
-    except:
+    except ValueError:
         return default
 
 
@@ -17,7 +17,7 @@ def read_int_setting(settings, setting_name, default=0):
             return int(s)
         else:
             return default
-    except:
+    except ValueError:
         return default
 
 
