@@ -128,7 +128,11 @@ def proxy_process(log_queue, incoming, outgoing, identifier,
         # move to a new process group (won't be signalled with ctrl+c)
         os.setpgrp()
 
-    device_logger.debug("Proxy process starting")
+    arg_strs = [repr(x) for x in ffargs]
+    arg_strs.extend("{}={}".format(k, repr(v)) for k, v in ffkwargs.items())
+    find_func_str = "{}({})".format(find_func.__name__, ", ".join(arg_strs))
+    device_logger.debug("Proxy process starting with %s", find_func_str)
+
     me = psutil.Process(os.getpid())
     try:
         try:
@@ -137,6 +141,7 @@ def proxy_process(log_queue, incoming, outgoing, identifier,
         except Exception as e:
             device_logger.exception("Exception")
             outgoing.put(e)
+        device_logger.debug("Proxy running")
         if device:
             proxy_ids[None] = device
             device_identifiers[device] = identifier
@@ -411,6 +416,7 @@ class DeviceProxyManager:
     def __init__(self):
         self.setup_logging()
         self.proxies = []
+        self.next_proxy_id = 0
 
     def setup_logging(self):
         local_handler = RemoteToLocalLogHandler(__name__ + ".remote")
@@ -435,6 +441,9 @@ class DeviceProxyManager:
         # clear finished proxies first
         self.clear_finished_proxies()
 
+        identifier = "{}:{}".format(self.next_proxy_id, identifier)
+        self.next_proxy_id += 1
+
         proxy = DeviceProxy(self.logQueue, identifier, find_func,
                             *args, **kwargs)
         self.proxies.append(proxy)
